@@ -1,8 +1,13 @@
+from __future__ import absolute_import
+
 import mock
+
 from django import test
 from django.core.exceptions import ImproperlyConfigured
 from django.http import HttpResponse
+
 from braces.views import AjaxResponseMixin
+
 from .compat import force_text
 from .factories import ArticleFactory, UserFactory
 from .helpers import TestViewHelper
@@ -108,13 +113,13 @@ class TestJSONResponseMixin(TestViewHelper, test.TestCase):
         self.assertIn(a1.title, titles)
         self.assertIn(a2.title, titles)
 
-    def test_missing_content_type(self):
+    def test_bad_content_type(self):
         """
         ImproperlyConfigured exception should be raised if content_type
         attribute is not set correctly.
         """
         with self.assertRaises(ImproperlyConfigured):
-            self.dispatch_view(self.build_request(), content_type=None)
+            self.dispatch_view(self.build_request(), content_type=['a'])
 
     def test_pretty_json(self):
         """
@@ -150,7 +155,6 @@ class TestJsonRequestResponseMixin(TestViewHelper, test.TestCase):
         self.assertEqual(response.status_code, 200)
         self.assertEqual(response_json, self.request_dict)
 
-
     def test_get_request_json_improperly_formatted(self):
         """
         Improperly formatted JSON requests should make request_json == None
